==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_fa_IR.ts <==
<TS language="fa_IR" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>گشایش حسابی جدید</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>کپی کردن حساب انتخاب شده به حافظه سیستم - کلیپ بورد</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>کپی</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>حذف آدرس های انتخاب شده از لیست</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>حذف</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>دیالوگ رمزعبور</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>رمز/پَس فرِیز را وارد کنید</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>رمز/پَس فرِیز جدید را وارد کنید</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>رمز/پَس فرِیز را دوباره وارد کنید</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>امضا و پیام</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>و بازبینی</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>نمای کلی از wallet را نشان بده</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>تاریخچه تراکنش را باز کن</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>از "درخواست نامه"/ application خارج شو</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>و انتخابها</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>و رمزگذاری wallet</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>تغییر رمز/پَس فرِیز</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>رمز مربوط به رمزگذاریِ wallet را تغییر دهید</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>کیف پول</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>و ارسال</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;نمایش/ عدم نمایش و</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>و فایل</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>و تنظیمات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>و راهنما</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>روزآمد</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>در حال روزآمد سازی..</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>ارسال تراکنش</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>تراکنش دریافتی</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>wallet رمزگذاری شد و در حال حاضر قفل است</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>میزان وجه:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>میزان</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>تایید شده</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>ویرایش حساب</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>و برچسب</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>حساب&amp;</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>انتخاب/آپشن</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>و تایید</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>و رد</translation>
    </message>
    <message>
        <source>default</source>
        <translation>پیش فرض</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>فرم</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>ویرایش کنسول RPC</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>تعداد اتصال</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>زنجیره مجموعه تراکنش ها</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>تعداد زنجیره های حاضر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>سکه های ارسالی</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>وجوه ناکافی</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>میزان وجه:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>ارسال همزمان به گیرنده های متعدد</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>تایید عملیات ارسال </translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>و ارسال</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>و میزان وجه</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>پرداخت و به چه کسی</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>و برچسب</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt و A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>آدرس را بر کلیپ بورد کپی کنید</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt و P</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>و امضای پیام </translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt و A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>آدرس را بر کلیپ بورد کپی کنید</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt و P</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>و امضای پیام </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>این بخش جزئیات تراکنش را نشان می دهد</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading addresses...</source>
        <translation>لود شدن آدرسها..</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>وجوه ناکافی</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>لود شدن نمایه بلاکها..</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>wallet در حال لود شدن است...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>قابلیت برگشت به نسخه قبلی برای wallet امکان پذیر نیست</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>آدرس پیش فرض قابل ذخیره نیست</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>اسکنِ دوباره...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>اتمام لود شدن</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطا</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_fa_IR.ts <==
<TS language="fa_IR" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>گشایش حسابی جدید</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>کپی کردن حساب انتخاب شده به حافظه سیستم - کلیپ بورد</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>کپی</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>حذف آدرس های انتخاب شده از لیست</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>حذف</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>دیالوگ رمزعبور</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>رمز/پَس فرِیز را وارد کنید</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>رمز/پَس فرِیز جدید را وارد کنید</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>رمز/پَس فرِیز را دوباره وارد کنید</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>کیف پول</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>و بازبینی</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>نمای کلی از wallet را نشان بده</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>و ارسال</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>تاریخچه تراکنش را باز کن</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>از "درخواست نامه"/ application خارج شو</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>و انتخابها</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;نمایش/ عدم نمایش و</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>و رمزگذاری wallet</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>تغییر رمز/پَس فرِیز</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>رمز مربوط به رمزگذاریِ wallet را تغییر دهید</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>امضا و پیام</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>و فایل</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>و تنظیمات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>و راهنما</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>روزآمد</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>در حال روزآمد سازی..</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>ارسال تراکنش</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>تراکنش دریافتی</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>wallet رمزگذاری شد و در حال حاضر قفل است</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>میزان وجه:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>میزان</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>تایید شده</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>ویرایش حساب</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>و برچسب</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>حساب&amp;</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>انتخاب/آپشن</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>شبکه</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>و تایید</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>و رد</translation>
    </message>
    <message>
        <source>default</source>
        <translation>پیش فرض</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>فرم</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>ویرایش کنسول RPC</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>تعداد اتصال</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>زنجیره مجموعه تراکنش ها</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>تعداد زنجیره های حاضر</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>سکه های ارسالی</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>وجوه ناکافی</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>میزان وجه:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>ارسال همزمان به گیرنده های متعدد</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>تایید عملیات ارسال </translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>و ارسال</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>و میزان وجه</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>پرداخت و به چه کسی</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>پیام:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>و برچسب</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt و A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>آدرس را بر کلیپ بورد کپی کنید</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt و P</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>و امضای پیام </translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt و A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>آدرس را بر کلیپ بورد کپی کنید</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt و P</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>و امضای پیام </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>این بخش جزئیات تراکنش را نشان می دهد</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Loading addresses...</source>
        <translation>لود شدن آدرسها..</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>وجوه ناکافی</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>لود شدن نمایه بلاکها..</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>wallet در حال لود شدن است...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>آدرس پیش فرض قابل ذخیره نیست</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>اسکنِ دوباره...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>اتمام لود شدن</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطا</translation>
    </message>
</context>
</TS>
